'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _actions = require('./actions');

var _socket = require('socket.io-client');

var _socket2 = _interopRequireDefault(_socket);

var _util = require('./util');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CRITICAL_LEVEL = 100;

function createMiddleware() {
    return function (store) {
        var socketIOFailCount = 0;
        var socketIO = null;

        var initSocketIO = function initSocketIO() {
            socketIO = (0, _socket2.default)(window.location.origin, {
                path: (0, _util.getRootableUrl)('/socket/')
            });

            socketIO.on('event', function (event) {
                return store.dispatch(JSON.parse(event));
            });

            socketIO.on('disconnect', function () {
                socketIOFailCount++;
                if (socketIOFailCount > CRITICAL_LEVEL) {
                    window.location.reload();
                }
                initSocketIO();
            });
        };

        initSocketIO();

        return function (next) {
            return function (action) {
                var type = action.type,
                    types = action.types,
                    ids = action.ids;

                if (type === _actions.SET_SUBSCRIPTION) {
                    socketIO.emit('setSubscription', {
                        types: types || [],
                        ids: ids || []
                    });
                }

                return next(action);
            };
        };
    };
}

var middleware = typeof window === 'undefined' ? function () {
    return function () {
        return function (next) {
            return function (action) {
                return next(action);
            };
        };
    };
} : createMiddleware;

exports.default = middleware;